diff --git a/ChangeLog b/ChangeLog
index ab723eb..8e4f6ca 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,10 @@
+2016-12-06  Andrew Senkevich  <andrew.senkevich@intel.com>
+
+	[BZ #20539]
+	* math/Makefile (install-lib-ldscripts): added libm.a.
+	($(inst_libdir)/libm.a): added rule for installation as linker script.
+	* Makerules (install-lib.a): filter out install-lib-ldscripts.
+
 2016-12-06  Joseph Myers  <joseph@codesourcery.com>
 
 	[BZ #20916]
diff --git a/Makerules b/Makerules
index e865782..573c074 100644
--- a/Makerules
+++ b/Makerules
@@ -1190,7 +1190,8 @@ $(addprefix $(inst_sbindir)/,$(install-sbin)): \
 	$(do-install-program)
 endif
 ifdef install-lib
-install-lib.a := $(filter lib%.a,$(install-lib))
+install-lib.a := $(filter-out libm.a,$(filter lib%.a,$(install-lib)))
+install-lib.a := $(filter-out $(install-lib-ldscripts),$(install-lib.a))
 install-lib-non.a := $(filter-out lib%.a,$(install-lib))
 ifdef install-lib-non.a
 $(addprefix $(inst_libdir)/$(libprefix),$(install-lib-non.a)): \
diff --git a/math/Makefile b/math/Makefile
index 848b093..77031b1 100644
--- a/math/Makefile
+++ b/math/Makefile
@@ -128,10 +128,10 @@ generated += $(foreach s,.c .S,$(call type-foreach, $(calls:s_%=m_%$(s))))
 routines = $(call type-foreach, $(calls))
 
 ifeq ($(build-mathvec),yes)
-# We need to install libm.so as linker script
-# for more comfortable use of vector math library.
-install-lib-ldscripts := libm.so
-install_subdir: $(inst_libdir)/libm.so
+# We need to install libm.so and libm.a as linker scripts
+# for transparent use of vector math library.
+install-lib-ldscripts := libm.so libm.a
+install-others: $(inst_libdir)/libm.so $(inst_libdir)/libm.a
 $(inst_libdir)/libm.so: $(common-objpfx)format.lds \
 			$(libm) \
 			$(libmvec) \
@@ -142,6 +142,18 @@ $(inst_libdir)/libm.so: $(common-objpfx)format.lds \
 	      'AS_NEEDED ( $(libdir)/libmvec_nonshared.a $(slibdir)/libmvec.so$(libmvec.so-version) ) )' \
 	) > $@.new
 	mv -f $@.new $@
+
+install-others = $(inst_libdir)/libm.a
+$(inst_libdir)/libm.a: $(common-objpfx)format.lds \
+		       $(libm) \
+		       $(libmvec) \
+		       $(+force)
+	(echo '/* GNU ld script'; echo '*/';\
+	 cat $<; \
+	 echo 'GROUP ( $(libdir)/libm-$(lib-version).a $(libdir)/libmvec.a )' \
+	) > $@.new
+	cp $(objpfx)libm.a $(inst_libdir)/libm-$(lib-version).a
+	mv -f $@.new $@
 endif
 
 # Rules for the test suite.
